@@ -122,20 +122,21 @@ class SmartDriver(SeleniumDriverCore):
                     print(f'Classify time: {end - start}')
                 response = r.json()
                 if not response['success']:
-                    log.info(response['message'].replace(self.default_prod_url, self.url))
+                    classification_error_msg = response['message'].replace(self.default_prod_url, self.url)
+                    raise Exception(classification_error_msg)
+
                 run_key = response['screenshot_uuid']
                 msg = response.get('message', '')
                 msg = msg.replace(self.default_prod_url, self.url)
-                if response['success']:
-                    log.info(response['message'])
-                    element_box = response['predicted_element']
-                    if self.use_cdp:
-                        parent_elem = None
-                        real_elem = element_box
-                    else:
-                        real_elem = self._match_bounding_box_to_selenium_element(element_box, multiplier=self.multiplier)
-                        parent_elem = real_elem.parent
-                    element = ai_elem(parent_elem, real_elem, element_box, self.driver, self.multiplier)
+
+                element_box = response['predicted_element']
+                if self.use_cdp:
+                    parent_elem = None
+                    real_elem = element_box
+                else:
+                    real_elem = self._match_bounding_box_to_selenium_element(element_box, multiplier=self.multiplier)
+                    parent_elem = real_elem.parent
+                element = ai_elem(parent_elem, real_elem, element_box, self.driver, self.multiplier)
             except Exception:
                 logging.exception('exception during classification')
             return element, run_key, msg
